@@ -146,6 +146,7 @@ class OvsHost(linux.LinuxDevice):
 
         macaddr = self.ovs_get_interface(name, "mac_in_use").strip('"')
         kwargs["mac"] = macaddr
+        self.macs.append(macaddr)
         if kwargs.get("ip", None) :
             # Configure the ip address for the address for route
             self.cmd('ip link set %s up' %(name))
@@ -157,8 +158,8 @@ class OvsHost(linux.LinuxDevice):
                 self.ofctl_add_flow(bridge_name,
                     #"priority=65535,arp,arp_tpa=%s,actions=normal" %(ip.split("/")[0]),
                     #"priority=1,ip,nw_dst=%s actions=normal" %(ip.split("/")[0]),
-                    'priority=1,arp,arp_tpa=%s,arp_op=1,actions=move:"NXM_OF_ETH_SRC[]->NXM_OF_ETH_DST[]",mod_dl_src:"%s",load:"0x02->NXM_OF_ARP_OP[]",move:"NXM_NX_ARP_SHA[]->NXM_NX_ARP_THA[]",load:"0x%s->NXM_NX_ARP_SHA[]",move:"NXM_OF_ARP_SPA[]->NXM_OF_ARP_TPA[]",load:"0x%s->NXM_OF_ARP_SPA[]",in_port'%(ipaddr, macaddr, re.sub(r":", "", macaddr), "".join(f"{i:02x}" for i in ipaddr.packed)),
-                    'priority=1,icmp,nw_dst=%s,icmp_type=8,icmp_code=0,actions=push:"NXM_OF_ETH_SRC[]",push:"NXM_OF_ETH_DST[]",pop:"NXM_OF_ETH_SRC[]",pop:"NXM_OF_ETH_DST[]",push:"NXM_OF_IP_SRC[]",push:"NXM_OF_IP_DST[]",pop:"NXM_OF_IP_SRC[]",pop:"NXM_OF_IP_DST[]",load:"0xff->NXM_NX_IP_TTL[]",load:"0->NXM_OF_ICMP_TYPE[]",in_port' %(ipaddr),
+                    'priority=10000,arp,arp_tpa=%s,arp_op=1,actions=move:"NXM_OF_ETH_SRC[]->NXM_OF_ETH_DST[]",mod_dl_src:"%s",load:"0x02->NXM_OF_ARP_OP[]",move:"NXM_NX_ARP_SHA[]->NXM_NX_ARP_THA[]",load:"0x%s->NXM_NX_ARP_SHA[]",move:"NXM_OF_ARP_SPA[]->NXM_OF_ARP_TPA[]",load:"0x%s->NXM_OF_ARP_SPA[]",in_port'%(ipaddr, macaddr, re.sub(r":", "", macaddr), "".join(f"{i:02x}" for i in ipaddr.packed)),
+                    'priority=10000,icmp,nw_dst=%s,icmp_type=8,icmp_code=0,actions=push:"NXM_OF_ETH_SRC[]",push:"NXM_OF_ETH_DST[]",pop:"NXM_OF_ETH_SRC[]",pop:"NXM_OF_ETH_DST[]",push:"NXM_OF_IP_SRC[]",push:"NXM_OF_IP_DST[]",pop:"NXM_OF_IP_SRC[]",pop:"NXM_OF_IP_DST[]",load:"0xff->NXM_NX_IP_TTL[]",load:"0->NXM_OF_ICMP_TYPE[]",in_port' %(ipaddr),
                     )
 
     def add_device (self, bridge_name, *args, **kwargs):
@@ -186,9 +187,9 @@ class OvsHost(linux.LinuxDevice):
                 if self["fail-mode"] == "secure":
                     ipaddr = ipaddress.ip_interface(arg["ip"])
                     self.ofctl_add_flow(bridge_name,
-                        "priority=65535,arp,arp_tpa=%s,actions=output:%s"
+                        "priority=10000,arp,arp_tpa=%s,actions=output:%s"
                         %(ipaddr.ip, arg["ofport"]),
-                        "priority=60000,ip,nw_src=%s,nw_dst=%s,actions=output:%s" 
+                        "priority=10000,ip,nw_src=%s,nw_dst=%s,actions=output:%s" 
                         %(ipaddr.network, ipaddr.ip, arg["ofport"]))
             elif dtype == "vm":
                 self.__add_vm(bridge_name, arg)
@@ -309,9 +310,9 @@ class OvsHost(linux.LinuxDevice):
                 p["ofport"] = self.ovs_get_interface(port_name, "ofport")
                 ipaddr = ipaddress.ip_interface(p["ip"])
                 self.ofctl_add_flow(bridge_name,
-                    "priority=65535,arp,arp_tpa=%s,actions=output:%s"
+                    "priority=10000,arp,arp_tpa=%s,actions=output:%s"
                     %(ipaddr.ip, p["ofport"]),
-                    "priority=60000,ip,nw_src=%s,nw_dst=%s,actions=output:%s" 
+                    "priority=10000,ip,nw_src=%s,nw_dst=%s,actions=output:%s" 
                     %(ipaddr.network, ipaddr.ip, p["ofport"]))
 
     def add_vtep (self, bridge_name, vtep, *args):
@@ -326,42 +327,34 @@ class OvsHost(linux.LinuxDevice):
             ipaddr = ipaddress.ip_interface(arg["ip"]).ip
             vxlan_port = self.ovs_get_interface(vtep["name"], "ofport")
             self.ofctl_add_flow(bridge_name,
-                    "priority=65535,arp,arp_tpa=%s,actions=output:%s"
+                    "priority=1000,arp,arp_tpa=%s,actions=output:%s"
                     %(ipaddr, vxlan_port),
-                    "priority=60000,ip,nw_dst=%s,actions=output:%s" 
+                    "priority=1000,ip,nw_dst=%s,actions=output:%s" 
                     %(ipaddr, vxlan_port))
 
     def add_gateway (self, bridge_name, gw, *args):
         '''
         Add some flows to ofproto
         '''
-        #self.log("mac: %s" %(self.macs))
+        self.log("gw mac: %s" %(gw["mac"]))
+        self.log("mac: %s" %(self.macs))
         if (gw["mac"] not in self.macs):
             # gw is not on this node, Add it as if it's on this node.
             ipaddr = ipaddress.ip_interface(gw["ip"]).ip
             self.ofctl_add_flow(bridge_name,
-                    'priority=1,arp,arp_tpa=%s,arp_op=1,actions=move:"NXM_OF_ETH_SRC[]->NXM_OF_ETH_DST[]",mod_dl_src:"%s",load:"0x02->NXM_OF_ARP_OP[]",move:"NXM_NX_ARP_SHA[]->NXM_NX_ARP_THA[]",load:"0x%s->NXM_NX_ARP_SHA[]",move:"NXM_OF_ARP_SPA[]->NXM_OF_ARP_TPA[]",load:"0x%s->NXM_OF_ARP_SPA[]",in_port'%(ipaddr,
+                    'priority=1000,arp,arp_tpa=%s,arp_op=1,actions=move:"NXM_OF_ETH_SRC[]->NXM_OF_ETH_DST[]",mod_dl_src:"%s",load:"0x02->NXM_OF_ARP_OP[]",move:"NXM_NX_ARP_SHA[]->NXM_NX_ARP_THA[]",load:"0x%s->NXM_NX_ARP_SHA[]",move:"NXM_OF_ARP_SPA[]->NXM_OF_ARP_TPA[]",load:"0x%s->NXM_OF_ARP_SPA[]",in_port'%(ipaddr,
                         gw["mac"],
                         re.sub(r":", "", gw["mac"]),
                         "".join(f"{i:02x}" for i in ipaddr.packed)),
-                    'priority=1,icmp,nw_dst=%s,icmp_type=8,icmp_code=0,actions=push:"NXM_OF_ETH_SRC[]",push:"NXM_OF_ETH_DST[]",pop:"NXM_OF_ETH_SRC[]",pop:"NXM_OF_ETH_DST[]",push:"NXM_OF_IP_SRC[]",push:"NXM_OF_IP_DST[]",pop:"NXM_OF_IP_SRC[]",pop:"NXM_OF_IP_DST[]",load:"0xff->NXM_NX_IP_TTL[]",load:"0->NXM_OF_ICMP_TYPE[]",in_port' %(ipaddr))
+                    'priority=1000,icmp,nw_dst=%s,icmp_type=8,icmp_code=0,actions=push:"NXM_OF_ETH_SRC[]",push:"NXM_OF_ETH_DST[]",pop:"NXM_OF_ETH_SRC[]",pop:"NXM_OF_ETH_DST[]",push:"NXM_OF_IP_SRC[]",push:"NXM_OF_IP_DST[]",pop:"NXM_OF_IP_SRC[]",pop:"NXM_OF_IP_DST[]",load:"0xff->NXM_NX_IP_TTL[]",load:"0->NXM_OF_ICMP_TYPE[]",in_port' %(ipaddr))
 
         for d in args:
-            #self.log("d: %s" %(d))
-            #if d.get("type", None) not in ["vm", "container"]:
-            #    self.log("Don't support device type: %s" %(d.get("type", None)))
-            #    continue
             if (d["mac"] in self.macs):
                 # ONly change the mac and ttl on the same host.
                 self.ofctl_add_flow(bridge_name,
-                    "priority=10,ip,nw_dst=%s,action=mod_dl_src:%s,"
+                    "priority=1000,ip,nw_dst=%s,action=mod_dl_src:%s,"
                     "mod_dl_dst:%s,dec_ttl,output:%s"
                     %(d["ip"].split("/")[0], gw["mac"], d["mac"], d["ofport"]))
-            #else:
-            #    # It's on the other host, only forward
-            #    self.ofctl_add_flow(bridge_name,
-            #        "priority=10,ip,nw_dst=%s,action=output:%s"
-            #        %(d["ip"].split("/")[0], vxlan_port))
 
     def set_out_interface (self, bridge_name, out_if, *args):
         '''
@@ -375,9 +368,9 @@ class OvsHost(linux.LinuxDevice):
             ipaddr = ipaddress.ip_interface(arg["ip"]).ip
             vxlan_port = self.ovs_get_interface(out_if["name"], "ofport")
             self.ofctl_add_flow(bridge_name,
-                    "priority=65535,arp,arp_tpa=%s,actions=output:%s"
+                    "priority=1000,arp,arp_tpa=%s,actions=output:%s"
                     %(ipaddr, vxlan_port),
-                    "priority=60000,ip,nw_dst=%s,actions=output:%s" 
+                    "priority=1000,ip,nw_dst=%s,actions=output:%s" 
                     %(ipaddr, vxlan_port))
 
     def del_br (self, *args, **kwargs):
